@@ -96,7 +96,7 @@ def L_OSUE_Aggregator(ue_reports, eps_perm, eps_1):
     est_freq = ((sum(ue_reports) - n * q1 * (p2 - q2) - n * q2) / (n * (p1 - q1) * (p2 - q2))).clip(0)
 
     # Re-normalized estimated frequency
-    norm_est_freq = est_freq / sum(est_freq)
+    norm_est_freq = np.nan_to_num(est_freq / sum(est_freq))
 
-    return np.nan_to_num(norm_est_freq)
+    return norm_est_freq
 
